@@ -2,7 +2,7 @@ package App::CPAN::Fresh;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use base qw(App::Cmd::Simple);
 
@@ -88,11 +88,13 @@ sub inject {
     my($self, $dist) = @_;
     $dist =~ s/::/-/g;
 
-    my $res = $self->call("/search", { q => "$dist group:cpan" });
-    for my $entry (@{$res->{entries}}) {
-        my $info = $self->parse_entry($entry->{body}, $entry->{date}) or next;
-        if ($info->{dist} eq $dist) {
-            return $self->do_inject($info);
+    for my $method ([ "/feed/cpan" ], [ "/search", { q => "$dist group:cpan" } ]) {
+        my $res = $self->call($method->[0], $method->[1]);
+        for my $entry (@{$res->{entries}}) {
+            my $info = $self->parse_entry($entry->{body}, $entry->{date}) or next;
+            if ($info->{dist} eq $dist) {
+                return $self->do_inject($info);
+            }
         }
     }
 
@@ -173,7 +175,7 @@ __END__
 
 =head1 NAME
 
-App::CPAN::Fresh - backend for I<cpanf> command
+App::CPAN::Fresh - Query and install CPAN modules realtime from the fresh mirror
 
 =head1 DESCRIPTION
 
